<?php

use App\Controllers\AuthController;
use App\Controllers\HomeController;
use App\Controllers\KanbanController;
use App\Controllers\NotificationController;
use App\Controllers\SettingController;
use App\Controllers\FinanzasController;
use App\Controllers\FitnessController;
use App\Controllers\EventosController;
use Symfony\Component\HttpFoundation\Request;

return [
    /**
     * Rutas de la aplicación
     */
    [
        "method" => "GET",
        "uri" => "/home",
        "target" => [HomeController::class, "showHome"],
        "protected" => true,
    ],

    /*
     * Rutas del Módulo Fitness
     */
    [
        "method" => "GET",
        "uri" => "/fitness/rutinas",
        "target" => [FitnessController::class, "showRutinas"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/fitness/rutinas/crear",
        "target" => [FitnessController::class, "showCrearRutina"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/fitness/rutinas/crear",
        "target" => [FitnessController::class, "createRutina"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/fitness/rutinas/editar/[i:id]",
        "target" => [FitnessController::class, "showEditarRutina"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/fitness/rutinas/editar/[i:id]",
        "target" => [FitnessController::class, "editRutina"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/fitness/rutinas/eliminar",
        "target" => [FitnessController::class, "deleteRutina"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/fitness/recetas",
        "target" => [FitnessController::class, "showRecetas"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/fitness/recetas/crear",
        "target" => [FitnessController::class, "showCrearReceta"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/fitness/recetas/crear",
        "target" => [FitnessController::class, "createReceta"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/fitness/recetas/editar/[i:id]",
        "target" => [FitnessController::class, "showEditarReceta"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/fitness/recetas/editar/[i:id]",
        "target" => [FitnessController::class, "editReceta"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/fitness/recetas/eliminar",
        "target" => [FitnessController::class, "deleteReceta"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/fitness/seguimiento",
        "target" => [FitnessController::class, "showSeguimiento"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/fitness/seguimiento/registrar",
        "target" => [FitnessController::class, "registrarActividad"],
        "protected" => true,
    ],
    
    /*
     * Rutas de Tareas
     */
    [
        "method" => "GET",
        "uri" => "/tareas",
        "target" => [KanbanController::class, "getAllTasks"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/tarea/get/[i:id]",
        "target" => [KanbanController::class, "getTask"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/tarea/create",
        "target" => [KanbanController::class, "createTask"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/tarea/update",
        "target" => [KanbanController::class, "updateTask"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/tarea/update-status",
        "target" => [KanbanController::class, "updateTaskStatus"],
        "protected" => true,
    ],    
    [
        "method" => "POST",
        "uri" => "/tarea/delete",
        "target" => [KanbanController::class, "deleteTask"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/tareas/kanban",
        "target" => [KanbanController::class, "showIndex"],
        "protected" => true,
    ],


    /*
     * Rutas del Módulo Finanzas
     */
    [
        "method" => "GET",
        "uri" => "/finanzas/ingresos",
        "target" => [FinanzasController::class, "showIngresos"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/finanzas/ingresos/crear",
        "target" => [FinanzasController::class, "createIngreso"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/finanzas/ingresos/eliminar",
        "target" => [FinanzasController::class, "deleteIngreso"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/finanzas/gastos",
        "target" => [FinanzasController::class, "showGastos"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/finanzas/gastos/crear",
        "target" => [FinanzasController::class, "createGasto"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/finanzas/gastos/eliminar",
        "target" => [FinanzasController::class, "deleteGasto"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/finanzas/presupuestos",
        "target" => [FinanzasController::class, "showPresupuestos"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/finanzas/presupuestos/crear",
        "target" => [FinanzasController::class, "createPresupuesto"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/finanzas/presupuestos/eliminar",
        "target" => [FinanzasController::class, "deletePresupuesto"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/finanzas/reportes",
        "target" => [FinanzasController::class, "showReportes"],
        "protected" => true,
    ],

    /*
     * Rutas del Módulo Eventos
     */
    [
        "method" => "GET",
        "uri" => "/eventos/crear",
        "target" => [EventosController::class, "showCrearEvento"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/eventos/crear",
        "target" => [EventosController::class, "createEvento"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/eventos/calendario",
        "target" => [EventosController::class, "showCalendario"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/eventos/recordatorios",
        "target" => [EventosController::class, "showRecordatorios"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/eventos/recordatorios/crear",
        "target" => [EventosController::class, "createRecordatorio"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/eventos/recordatorios/eliminar",
        "target" => [EventosController::class, "deleteRecordatorio"],
        "protected" => true,
    ],

    /*
     * Rutas de Notificaciones
     */
    [
        "method" => "GET",
        "uri" => "/notificaciones",
        "target" => [NotificationController::class, "showIndex"],
        "protected" => true,
    ],
    /*
     * Rutas de Configuraciones
     */
    [
        "method" => "GET",
        "uri" => "/configuracion",
        "target" => [SettingController::class, "showSettings"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/configuracion/update",
        "target" => [SettingController::class, "updateSettings"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/configuracion/correos/plantillas",
        "target" => [SettingController::class, "showPlantillas"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/configuracion/correos/plantillas/crear",
        "target" => [SettingController::class, "showCrearPlantilla"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/configuracion/correos/plantillas/crear",
        "target" => [SettingController::class, "createPlantilla"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/configuracion/correos/plantillas/editar/[i:id]",
        "target" => [SettingController::class, "showEditarPlantilla"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/configuracion/correos/plantillas/editar/[i:id]",
        "target" => [SettingController::class, "editPlantilla"],
        "protected" => true,
    ],
    [
        "method" => "POST",
        "uri" => "/configuracion/correos/plantillas/eliminar",
        "target" => [SettingController::class, "deletePlantilla"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/configuracion/correos/estados",
        "target" => [SettingController::class, "showEstados"],
        "protected" => true,
    ],
    [
        "method" => "GET",
        "uri" => "/configuracion/correos/historial",
        "target" => [SettingController::class, "showHistorial"],
        "protected" => true,
    ],
    /*
     * Rutas de autenticación
     */
    [
        "method" => "GET",
        "uri" => "/login",
        "target" => function () {
            (new AuthController())->showLogin();
        },
        "protected" => false,
    ],
    [
        "method" => "POST",
        "uri" => "/login",
        "target" => function () {
            $request = Request::createFromGlobals();
            (new AuthController())->login($request);
        },
        "protected" => false,
    ],
    [
        "method" => "GET",
        "uri" => "/register",
        "target" => function () {
            (new AuthController())->showRegister();
        },
        "protected" => false,
    ],
    [
        "method" => "POST",
        "uri" => "/register",
        "target" => function () {
            $request = Request::createFromGlobals();
            (new AuthController())->register($request);
        },
        "protected" => false,
    ],
    [
        "method" => "GET",
        "uri" => "/logout",
        "target" => function () {
            (new AuthController())->logout();
        },
        "protected" => true,
    ],
];
