<?php

namespace App\Controllers;

use App\Entities\Task;
use App\Repositories\TaskRepository;
use App\Core\Database;
use App\Core\HttpHelper;

use App\Helpers\AuthHelper;

class KanbanController extends BaseController
{
    protected TaskRepository $taskRepository;

    public function __construct()
    {
        $database = new Database();
        $this->taskRepository = new TaskRepository($database);
        parent::__construct($this->taskRepository);
    }

    public function showIndex()
    {
        $tasks = $this->taskRepository->getAll();
        $this->render("modules/tareas/kanban", compact('tasks'));
    }

    public function getAllTasks()
    {
        $tasks = $this->taskRepository->getAll();
        HttpHelper::createJsonResponse(['tasks' => $tasks], 200);
    }

    public function getTask($id)
    {
        $task = $this->taskRepository->findById($id);

        if ($task) {
            HttpHelper::createJsonResponse($task);
        } else {
            HttpHelper::createJsonResponse(["message" => "No se encontró la tarea"], 404);
        }
    }

    public function createTask()
    {
        $request = HttpHelper::getRequest();
        $userId = AuthHelper::getUserIdFromToken();

        if (!$userId) {
            HttpHelper::createJsonResponse(["message" => "Usuario no autenticado."], 401);
            return;
        }

        $data = [
            'task_title' => HttpHelper::getParam($request, 'task_title', '', FILTER_SANITIZE_STRING),
            'description' => HttpHelper::getParam($request, 'description', null, FILTER_SANITIZE_STRING),
            'due_date' => HttpHelper::getParam($request, 'due_date', null, FILTER_SANITIZE_STRING),
            'color' => HttpHelper::getParam($request, 'color', '#e9ecef', FILTER_SANITIZE_STRING),
            'status_id' => HttpHelper::getParam($request, 'status_id', 1, FILTER_VALIDATE_INT),
            'user_id' => $userId,
        ];

        error_log("Datos recibidos para la creación de la tarea: " . print_r($data, true));

        $task_id = $this->taskRepository->insert($data);

        if ($task_id) {
            HttpHelper::createJsonResponse(["task_id" => $task_id], 201);
        } else {
            HttpHelper::createJsonResponse(["message" => "No se pudo crear la tarea"], 400);
        }
    }


    public function updateTask()
    {
        $request = HttpHelper::getRequest();
        $taskId = HttpHelper::getParam($request, 'task_id', null, FILTER_VALIDATE_INT);
        if (!$taskId) {
            HttpHelper::createJsonResponse(["message" => "El ID de la tarea es obligatorio."], 400);
            return;
        }

        $data = [
            'task_title' => HttpHelper::getParam($request, 'task_title', '', FILTER_SANITIZE_STRING),
            'description' => HttpHelper::getParam($request, 'description', null, FILTER_SANITIZE_STRING),
            'due_date' => HttpHelper::getParam($request, 'due_date', null, FILTER_SANITIZE_STRING),
            'color' => HttpHelper::getParam($request, 'color', '#e9ecef', FILTER_SANITIZE_STRING),
            'status_id' => HttpHelper::getParam($request, 'status_id', 1, FILTER_VALIDATE_INT)
        ];

        if ($this->taskRepository->update($taskId, $data)) {
            HttpHelper::createJsonResponse(["message" => "Tarea actualizada exitosamente."]);
        } else {
            HttpHelper::createJsonResponse(["message" => "Error al actualizar la tarea."], 500);
        }
    }

    public function updateTaskStatus()
    {
        $request = HttpHelper::getRequest();
        $taskId = HttpHelper::getParam($request, 'task_id', null, FILTER_VALIDATE_INT);
        if (!$taskId) {
            HttpHelper::createJsonResponse(["message" => "El ID de la tarea es obligatorio."], 400);
            return;
        }

        $statusId = HttpHelper::getParam($request, 'status_id', null, FILTER_VALIDATE_INT);
        if (!$statusId) {
            HttpHelper::createJsonResponse(["message" => "El ID de estado es obligatorio."], 400);
            return;
        }

        $data = [
            'status_id' => $statusId,
            'updated_at' => date('Y-m-d H:i:s')
        ];

        if ($this->taskRepository->update($taskId, $data)) {
            HttpHelper::createJsonResponse(["message" => "Estado de la tarea actualizado exitosamente."]);
        } else {
            HttpHelper::createJsonResponse(["message" => "Error al actualizar el estado de la tarea."], 500);
        }
    }

    public function deleteTask()
    {
        $request = HttpHelper::getRequest();
        $taskId = HttpHelper::getParam($request, 'task_id', null, FILTER_VALIDATE_INT);
        if (!$taskId) {
            HttpHelper::createJsonResponse(["message" => "El ID de la tarea es obligatorio."], 400);
            return;
        }

        if ($this->taskRepository->delete($taskId)) {
            HttpHelper::createJsonResponse(["message" => "Tarea eliminada exitosamente."]);
        } else {
            HttpHelper::createJsonResponse(["message" => "Error al eliminar la tarea."], 500);
        }
    }

}
